@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,6 +22,7 @@
 #include "configurecustomsettingdialog.h"
 #include "kdebugsettingsutil.h"
 #include <KLocalizedString>
+#include <KListWidgetSearchLine>
 #include <KMessageBox>
 #include <QVBoxLayout>
 #include <QHBoxLayout>
@@ -33,51 +34,59 @@
 CustomDebugSettingsPage::CustomDebugSettingsPage(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+
+    QLabel *lab = new QLabel(i18n("Rules:"), this);
+    lab->setObjectName(QStringLiteral("custom_label"));
+    mainLayout->addWidget(lab);
+
+    QHBoxLayout *horizontalLayout = new QHBoxLayout;
+    horizontalLayout->setMargin(0);
+    mainLayout->addLayout(horizontalLayout);
 
     QVBoxLayout *vbox = new QVBoxLayout;
-    mainLayout->addLayout(vbox);
+    horizontalLayout->addLayout(vbox);
 
-    QLabel *lab = new QLabel(i18n("Rules:"));
-    lab->setObjectName(QStringLiteral("custom_label"));
-    vbox->addWidget(lab);
-
-    mListWidget = new QListWidget;
+    mListWidget = new QListWidget(this);
     mListWidget->setObjectName(QStringLiteral("custom_listwidget"));
+    mListWidget->setSelectionMode(QAbstractItemView::MultiSelection);
     connect(mListWidget, &QListWidget::itemSelectionChanged, this, &CustomDebugSettingsPage::updateButtons);
     connect(mListWidget, &QListWidget::itemDoubleClicked, this, &CustomDebugSettingsPage::slotEditRule);
+    KListWidgetSearchLine *searchLine = new KListWidgetSearchLine(this, mListWidget);
+    searchLine->setObjectName(QStringLiteral("searchline"));
+    searchLine->setPlaceholderText(i18n("Search..."));
+    vbox->addWidget(searchLine);
     vbox->addWidget(mListWidget);
 
     QVBoxLayout *buttonLayout = new QVBoxLayout;
-    mainLayout->addLayout(buttonLayout);
+    horizontalLayout->addLayout(buttonLayout);
 
-    mAddRule = new QPushButton(i18n("Add..."));
+    mAddRule = new QPushButton(i18n("Add..."), this);
     mAddRule->setObjectName(QStringLiteral("add_rule"));
     buttonLayout->addWidget(mAddRule);
     connect(mAddRule, &QAbstractButton::clicked, this, &CustomDebugSettingsPage::slotAddRule);
 
-    mEditRule = new QPushButton(i18n("Edit..."));;
+    mEditRule = new QPushButton(i18n("Edit..."), this);
     mEditRule->setObjectName(QStringLiteral("edit_rule"));
     buttonLayout->addWidget(mEditRule);
     connect(mEditRule, &QAbstractButton::clicked, this, &CustomDebugSettingsPage::slotEditRule);
 
-    mRemoveRule = new QPushButton(i18n("Remove..."));
+    mRemoveRule = new QPushButton(i18n("Remove..."), this);
     mRemoveRule->setObjectName(QStringLiteral("remove_rule"));
     buttonLayout->addWidget(mRemoveRule);
     buttonLayout->addStretch();
-    connect(mRemoveRule, &QAbstractButton::clicked, this, &CustomDebugSettingsPage::slotRemoveRule);
+    connect(mRemoveRule, &QAbstractButton::clicked, this, &CustomDebugSettingsPage::slotRemoveRules);
     updateButtons();
 }
 
 CustomDebugSettingsPage::~CustomDebugSettingsPage()
 {
-
 }
 
 void CustomDebugSettingsPage::updateButtons()
 {
-    mEditRule->setEnabled(mListWidget->currentItem());
-    mRemoveRule->setEnabled(mListWidget->currentItem());
+    mEditRule->setEnabled(mListWidget->selectedItems().count() == 1);
+    mRemoveRule->setEnabled(!mListWidget->selectedItems().isEmpty());
 }
 
 void CustomDebugSettingsPage::fillList(const LoggingCategory::List &list)
@@ -113,7 +122,7 @@ void CustomDebugSettingsPage::fillList(const LoggingCategory::List &list)
     }
 }
 
-LoggingCategory::List CustomDebugSettingsPage::rules()
+LoggingCategory::List CustomDebugSettingsPage::rules() const
 {
     LoggingCategory::List lst;
     const int number(mListWidget->count());
@@ -148,29 +157,38 @@ LoggingCategory::List CustomDebugSettingsPage::rules()
     return lst;
 }
 
-void CustomDebugSettingsPage::slotRemoveRule()
+void CustomDebugSettingsPage::slotRemoveRules()
 {
-    QListWidgetItem *item = mListWidget->currentItem();
-    if (item) {
-        if (KMessageBox::Yes == KMessageBox::warningYesNo(this, i18n("Do you want to remove this rule \"%1\"?", item->text()))) {
-            delete item;
-        }
+    QList<QListWidgetItem *> lst = mListWidget->selectedItems();
+    if (lst.isEmpty()) {
+        return;
+    }
+    const QString str = i18np("Do you want to remove this rule?", "Do you want to remove these %1 rules?", lst.count());
+
+    if (KMessageBox::No == KMessageBox::warningYesNo(this, str)) {
+        return;
+    }
+    for (int i = 0; i < lst.count(); ++i) {
+        QListWidgetItem *item = lst.at(i);
+        delete item;
     }
 }
 
 void CustomDebugSettingsPage::slotEditRule()
 {
-    QListWidgetItem *item = mListWidget->currentItem();
-    if (item) {
-        QPointer<ConfigureCustomSettingDialog> dlg = new ConfigureCustomSettingDialog(this);
-        dlg->setRule(item->text());
-        if (dlg->exec()) {
-            const QString ruleStr = dlg->rule();
-            if (!ruleStr.isEmpty()) {
-                item->setText(dlg->rule());
+    if (mListWidget->selectedItems().count() == 1) {
+        QListWidgetItem *item = mListWidget->selectedItems().at(0);
+        if (item) {
+            QPointer<ConfigureCustomSettingDialog> dlg = new ConfigureCustomSettingDialog(this);
+            dlg->setRule(item->text());
+            if (dlg->exec()) {
+                const QString ruleStr = dlg->rule();
+                if (!ruleStr.isEmpty()) {
+                    item->setText(dlg->rule());
+                }
             }
+            delete dlg;
         }
-        delete dlg;
     }
 }
 
