@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -25,6 +25,7 @@
 #include "kdebugsettingsutil.h"
 #include "categorywarning.h"
 #include "loadcategoriesjob.h"
+#include "saverulesjob.h"
 
 #include <KLocalizedString>
 #include <KConfigGroup>
@@ -46,14 +47,13 @@
 KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     : QDialog(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     mCategoryWarning = new CategoryWarning(this);
     mCategoryWarning->setObjectName(QStringLiteral("categorywarning"));
     mainLayout->addWidget(mCategoryWarning);
 
-    mTabWidget = new QTabWidget;
+    mTabWidget = new QTabWidget(this);
     mTabWidget->setObjectName(QStringLiteral("tabwidget"));
     mainLayout->addWidget(mTabWidget);
 
@@ -68,7 +68,7 @@ KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     mTabWidget->addTab(mEnvironmentSettingsRulesPage, i18n("Rules Settings With Environment Variable"));
     mTabWidget->setFocusPolicy(Qt::NoFocus);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help | QDialogButtonBox::Apply);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::RestoreDefaults | QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help | QDialogButtonBox::Apply, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
 
     QPushButton *saveAs = new QPushButton(i18n("Save As..."), this);
@@ -90,6 +90,7 @@ KDebugSettingsDialog::KDebugSettingsDialog(QWidget *parent)
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     connect(buttonBox, &QDialogButtonBox::helpRequested, this, &KDebugSettingsDialog::slotHelpRequested);
     connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &KDebugSettingsDialog::slotApply);
+    connect(buttonBox->button(QDialogButtonBox::RestoreDefaults), &QPushButton::clicked, this, &KDebugSettingsDialog::slotRestoreDefault);
     mainLayout->addWidget(buttonBox);
     readConfig();
     readQtLoggingFile();
@@ -131,7 +132,11 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
 {
     // KDE debug categories area
     const QString confAreasFile = QStandardPaths::locate(QStandardPaths::ConfigLocation, QStringLiteral("kde.categories"));
-    KDebugSettingsUtil::readLoggingCategories(confAreasFile, mCategoriesList, false);
+    if (confAreasFile.isEmpty()) {
+        qCWarning(KDEBUGSETTINGS_LOG) << "Impossible to find kde.categories file";
+    } else {
+        KDebugSettingsUtil::readLoggingCategories(confAreasFile, mCategoriesList, false);
+    }
 
     mRenameCategoriesList.clear();
     // Load *.renamecategories file in QStandardPaths::ConfigLocation for kde apps.
@@ -171,7 +176,6 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
         }
     }
 
-
     const QByteArray rulesFilePath = qgetenv("QT_LOGGING_CONF");
     if (!rulesFilePath.isEmpty()) {
         const QList<KDebugSettingsUtil::LoadLoggingCategory> envCategories = KDebugSettingsUtil::readLoggingQtCategories(QString::fromLatin1(rulesFilePath));
@@ -200,24 +204,16 @@ void KDebugSettingsDialog::readCategoriesFiles(const QString &path)
     }
 }
 
-bool KDebugSettingsDialog::saveRules(const QString &path)
+bool KDebugSettingsDialog::saveRules(const QString &path, bool forceSavingAllRules)
 {
-    QFile qtlogging(path);
-    if (!qtlogging.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Truncate)) {
+    SaveRulesJob job;
+    job.setFileName(path);
+    job.setListCustom(mCustomSettingsPage->rules());
+    job.setListKde(mKdeApplicationSettingsPage->rules(forceSavingAllRules));
+    if (!job.start()) {
         KMessageBox::error(this, i18n("\'%1\' cannot be opened. Please verify it.", path));
         return false;
     }
-    //Save Rules
-    const LoggingCategory::List lstKde = mKdeApplicationSettingsPage->rules();
-    const LoggingCategory::List lstCustom = mCustomSettingsPage->rules();
-    QTextStream out(&qtlogging);
-    out << QLatin1String("[Rules]\n");
-    for (LoggingCategory cat : lstKde) {
-        out << cat.createRule() + QLatin1Char('\n');
-    }
-    for (LoggingCategory cat : lstCustom) {
-        out << cat.createCustomRule() + QLatin1Char('\n');
-    }
     return true;
 }
 
@@ -247,7 +243,7 @@ void KDebugSettingsDialog::slotApply()
 
 void KDebugSettingsDialog::slotInsertCategories()
 {
-    const QString path = QFileDialog::getOpenFileName(this, i18n("Insert Categories"));
+    const QString path = QFileDialog::getOpenFileName(this, i18n("Insert Categories"), QString(), QStringLiteral("%1 (*.categories)").arg(i18n("Categories Files")));
     if (!path.isEmpty()) {
         const KdeLoggingCategory::List insertCategoriesList = KDebugSettingsUtil::readLoggingCategoriesForInserting(path, mCategoriesList);
         LoggingCategory::List newCategories;
@@ -255,6 +251,7 @@ void KDebugSettingsDialog::slotInsertCategories()
             LoggingCategory loggingCat;
             loggingCat.description = cat.description;
             loggingCat.logName = cat.logName;
+            loggingCat.defaultCategoryType = KDebugSettingsUtil::convertCategoryTypeFromString(cat.defaultCategory);
             if (loggingCat.isValid()) {
                 newCategories.append(loggingCat);
             }
@@ -267,7 +264,7 @@ void KDebugSettingsDialog::slotSaveAs()
 {
     const QString path = QFileDialog::getSaveFileName(this, i18n("Save As"));
     if (!path.isEmpty()) {
-        saveRules(path);
+        saveRules(path, true);
     }
 }
 
@@ -278,3 +275,8 @@ void KDebugSettingsDialog::slotLoad()
         readCategoriesFiles(path);
     }
 }
+
+void KDebugSettingsDialog::slotRestoreDefault()
+{
+    mKdeApplicationSettingsPage->restoreToDefault();
+}
