@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -45,9 +45,10 @@ private:
     void slotSaveAs();
     void slotLoad();
     void slotInsertCategories();
+    void slotRestoreDefault();
 
     void readQtLoggingFile();
-    bool saveRules(const QString &path);
+    bool saveRules(const QString &path, bool forceSavingAllRules = false);
     bool saveInQtLogging();
     void readCategoriesFiles(const QString &path);
     void saveConfig();
