@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -23,6 +23,7 @@
 #include <QVector>
 #include <QObject>
 #include <QString>
+#include <QDebug>
 
 struct LoggingCategory {
     enum LoggingType {
@@ -38,8 +39,12 @@ struct LoggingCategory {
     LoggingCategory();
 
     explicit LoggingCategory(const QString &description, const QString &logName, LoggingType loggingType, bool enabled)
-        : description(description), logName(logName), loggingType(loggingType), enabled(enabled) {}
-
+        : description(description)
+        , logName(logName)
+        , loggingType(loggingType)
+        , enabled(enabled)
+    {
+    }
 
     typedef QVector<LoggingCategory> List;
     bool operator ==(const LoggingCategory &other) const;
@@ -50,10 +55,12 @@ struct LoggingCategory {
 
     QString description;
     QString logName;
-    LoggingType loggingType;
-    bool enabled;
-
+    LoggingType loggingType = Info;
+    LoggingType defaultCategoryType = Info;
+    bool enabled = true;
 };
+QDebug operator<<(QDebug debug, const LoggingCategory &cat);
+
 Q_DECLARE_TYPEINFO(LoggingCategory, Q_MOVABLE_TYPE);
 Q_DECLARE_METATYPE(LoggingCategory)
 Q_DECLARE_METATYPE(LoggingCategory::LoggingType)
